var NAVTREEINDEX0 =
{
"Boolean_set_operations_2_2bezier_traits_adapter2_8cpp-example.html":[5,0],
"Boolean_set_operations_2_2bezier_traits_adapter_8cpp-example.html":[5,1],
"Boolean_set_operations_2_2circle_segment_8cpp-example.html":[5,2],
"Boolean_set_operations_2_2conic_traits_adapter_8cpp-example.html":[5,3],
"Boolean_set_operations_2_2connect_polygon_8cpp-example.html":[5,4],
"Boolean_set_operations_2_2do_intersect_8cpp-example.html":[5,5],
"Boolean_set_operations_2_2draw_polygon_set_8cpp-example.html":[5,6],
"Boolean_set_operations_2_2dxf_union_8cpp-example.html":[5,7],
"Boolean_set_operations_2_2sequence_8cpp-example.html":[5,8],
"Boolean_set_operations_2_2set_union_8cpp-example.html":[5,9],
"Boolean_set_operations_2_2simple_join_intersect_8cpp-example.html":[5,10],
"Boolean_set_operations_2_2symmetric_difference_8cpp-example.html":[5,11],
"annotated.html":[4],
"citelist.html":[3],
"classAosDirectionalXMonotoneTraits__2.html":[1,0,0,0],
"classAosDirectionalXMonotoneTraits__2.html#a1cbf9c8f8ca2628ddd884525c543df42":[1,0,0,0,1],
"classAosDirectionalXMonotoneTraits__2.html#a4c1413e395b8d9a225995a0c474bc2fe":[1,0,0,0,7],
"classAosDirectionalXMonotoneTraits__2.html#a571296b34853c40ece25dda872c80f73":[1,0,0,0,2],
"classAosDirectionalXMonotoneTraits__2.html#a63c5db90d17ac0ead49f25f20ff9415b":[1,0,0,0,10],
"classAosDirectionalXMonotoneTraits__2.html#a68184b5284e0830198eaf446e9dc2564":[1,0,0,0,4],
"classAosDirectionalXMonotoneTraits__2.html#a75e3eb427372d013673ee82d90c0db30":[1,0,0,0,5],
"classAosDirectionalXMonotoneTraits__2.html#a79fbc857b2dce2431ab8d984864d25fe":[1,0,0,0,8],
"classAosDirectionalXMonotoneTraits__2.html#a9359894559ad36d6ebb9caaa2e034e35":[1,0,0,0,9],
"classAosDirectionalXMonotoneTraits__2.html#ab3244ffe08d41c206ca17079708580e0":[1,0,0,0,6],
"classAosDirectionalXMonotoneTraits__2.html#acd0aa4159804e0a1ecba0277fe042586":[1,0,0,0,0],
"classAosDirectionalXMonotoneTraits__2.html#ad5f02997cf9353bd52351c90d0fdc148":[1,0,0,0,3],
"classArrDirectionalTraits_1_1AreMergeable__2.html":[1,0,0,1],
"classArrDirectionalTraits_1_1AreMergeable__2.html#a0d5f85e020f4549c51d1bbebccdb3a1b":[1,0,0,1,0],
"classArrDirectionalTraits_1_1CompareEndpointsXy__2.html":[1,0,0,2],
"classArrDirectionalTraits_1_1CompareEndpointsXy__2.html#a87e5b179713620bbda5d13bddcb1a903":[1,0,0,2,0],
"classArrDirectionalTraits_1_1ConstructOpposite__2.html":[1,0,0,3],
"classArrDirectionalTraits_1_1ConstructOpposite__2.html#a69536a53c75f8ce19255ce85506c849c":[1,0,0,3,0],
"classArrDirectionalTraits_1_1Intersect__2.html":[1,0,0,4],
"classArrDirectionalTraits_1_1Intersect__2.html#a5ca1f63d87def998b7dfa7d2af8a0a8f":[1,0,0,4,0],
"classArrDirectionalTraits_1_1Merge__2.html":[1,0,0,5],
"classArrDirectionalTraits_1_1Merge__2.html#ac3b7ea1ad4f2ed3ea8161bc8dba70add":[1,0,0,5,0],
"classArrDirectionalTraits_1_1Split__2.html":[1,0,0,6],
"classArrDirectionalTraits_1_1Split__2.html#a6a95bcbe3c3c915e125c209a0981b72c":[1,0,0,6,0],
"classCGAL_1_1General__polygon__2.html":[1,0,13],
"classCGAL_1_1General__polygon__2.html#a1578ba31273af33ff54625d321615970":[1,0,13,6],
"classCGAL_1_1General__polygon__2.html#a24fdf71d1019ef5434cb5b5f10da61b5":[1,0,13,0],
"classCGAL_1_1General__polygon__2.html#a3ded69c9e0af390426dc86a0f8bd089b":[1,0,13,1],
"classCGAL_1_1General__polygon__2.html#aa65e28dd16fb0a85402e6bb0d2aa26d6":[1,0,13,9],
"classCGAL_1_1General__polygon__2.html#aaaa4397688d6e516277f2d0eac570418":[1,0,13,2],
"classCGAL_1_1General__polygon__2.html#aae701ae31978c30fc0bd912a564c115e":[1,0,13,7],
"classCGAL_1_1General__polygon__2.html#ac1032ea4819b62b4a56bfa4085136dbe":[1,0,13,4],
"classCGAL_1_1General__polygon__2.html#ad7b1f911c8e9f7cbc2b59a7372d6432b":[1,0,13,8],
"classCGAL_1_1General__polygon__2.html#ade0a2d5fa29db05425333ca894348866":[1,0,13,3],
"classCGAL_1_1General__polygon__2.html#ae77eb273ea8d8de1c3400efdaaef21ab":[1,0,13,5],
"classCGAL_1_1General__polygon__set__2.html":[1,0,14],
"classCGAL_1_1General__polygon__set__2.html#a07d7f9861b6157a19016ef8a2458b22c":[1,0,14,2],
"classCGAL_1_1General__polygon__set__2.html#a0f337095088a6eb692f08da6ddee6b28":[1,0,14,7],
"classCGAL_1_1General__polygon__set__2.html#a0fbb358af1dacd20774f9fdc598a3bea":[1,0,14,38],
"classCGAL_1_1General__polygon__set__2.html#a17a48e568ce9b6969eaa1af747dcf5f9":[1,0,14,45],
"classCGAL_1_1General__polygon__set__2.html#a186fb5a29321ff6f291090c79ae3c292":[1,0,14,35],
"classCGAL_1_1General__polygon__set__2.html#a1c10b9cf775e0a916f54afd0194fa4db":[1,0,14,31],
"classCGAL_1_1General__polygon__set__2.html#a1c9674a989396f1603d132695ae22689":[1,0,14,4],
"classCGAL_1_1General__polygon__set__2.html#a1fa68a9e21ca86ea913b2ba5710aa9a3":[1,0,14,26],
"classCGAL_1_1General__polygon__set__2.html#a20690997135eab18b695761018dcbe73":[1,0,14,24],
"classCGAL_1_1General__polygon__set__2.html#a251bdd1186c0c4aeae2fd1ebf91e9902":[1,0,14,46],
"classCGAL_1_1General__polygon__set__2.html#a2536d0e86f56e7f41bad407810d38257":[1,0,14,33],
"classCGAL_1_1General__polygon__set__2.html#a2d0bbbd0b61f30598e7fa936d34d9a78":[1,0,14,43],
"classCGAL_1_1General__polygon__set__2.html#a2f08bb08c258fe9ee5e8923fb550d2dd":[1,0,14,10],
"classCGAL_1_1General__polygon__set__2.html#a38a897d66b46f2dbe4955bc88b119135":[1,0,14,6],
"classCGAL_1_1General__polygon__set__2.html#a4edd575187af9aa5224489157605f425":[1,0,14,13],
"classCGAL_1_1General__polygon__set__2.html#a5220a0b69f65c2135e63b38b3d7d3781":[1,0,14,53],
"classCGAL_1_1General__polygon__set__2.html#a54a0dfd9778009ba36ef8c6cdb270314":[1,0,14,8],
"classCGAL_1_1General__polygon__set__2.html#a5e18f081bdc535ea1f87566b939e00f2":[1,0,14,15],
"classCGAL_1_1General__polygon__set__2.html#a6098d063d916b4bec3a7268ac63beeb1":[1,0,14,40],
"classCGAL_1_1General__polygon__set__2.html#a72c56fb7753555ff932f1fca3f1f5712":[1,0,14,50],
"classCGAL_1_1General__polygon__set__2.html#a769156c6b8a6d53ce4d288f6c6bd1318":[1,0,14,14],
"classCGAL_1_1General__polygon__set__2.html#a7cf04105b1e0cba6ac4442efabdd738c":[1,0,14,22],
"classCGAL_1_1General__polygon__set__2.html#a873c472029091a7d6c5ace6a2aa12ac6":[1,0,14,36],
"classCGAL_1_1General__polygon__set__2.html#a897de9631e72b08c2fcb44cf8e04fe56":[1,0,14,54],
"classCGAL_1_1General__polygon__set__2.html#a99ada8a1705bdd970cdf81a71cab502a":[1,0,14,20],
"classCGAL_1_1General__polygon__set__2.html#a9bca5d457fc8c8ac24bf920ebb946adc":[1,0,14,41],
"classCGAL_1_1General__polygon__set__2.html#a9d41f55871a2b65d1b421f19f155e6d4":[1,0,14,27],
"classCGAL_1_1General__polygon__set__2.html#a9e292b6eaa6c3c7b5166df4fe34b5be9":[1,0,14,25],
"classCGAL_1_1General__polygon__set__2.html#aa0e051243490f91df25f3b503c504e05":[1,0,14,42],
"classCGAL_1_1General__polygon__set__2.html#aa839f6a7da59bf5719412c040c359221":[1,0,14,28],
"classCGAL_1_1General__polygon__set__2.html#ab0271fcaec958067f7ce4d81eec14ccb":[1,0,14,47],
"classCGAL_1_1General__polygon__set__2.html#ab15b37e361961ebdbbc013582ec2dfbb":[1,0,14,12],
"classCGAL_1_1General__polygon__set__2.html#ab3903f5e011bd313e4871f5608dd4f6f":[1,0,14,23],
"classCGAL_1_1General__polygon__set__2.html#ab848fe13a8c5589fbe5cc842313f4f3c":[1,0,14,11],
"classCGAL_1_1General__polygon__set__2.html#aba665959aba438571f1e7f0522307ba6":[1,0,14,39],
"classCGAL_1_1General__polygon__set__2.html#abce804d687c42bdf257e894ac3736c51":[1,0,14,51],
"classCGAL_1_1General__polygon__set__2.html#abe38fb03266e72a3b3ac580d3d068c25":[1,0,14,56],
"classCGAL_1_1General__polygon__set__2.html#abed0cf3e9515d209da3d3ed763558d93":[1,0,14,0],
"classCGAL_1_1General__polygon__set__2.html#abf0c1d986a9fe4678b6c07c377e5b3c4":[1,0,14,1],
"classCGAL_1_1General__polygon__set__2.html#ac02ebeb4e77db6a897c90e367b318aff":[1,0,14,49],
"classCGAL_1_1General__polygon__set__2.html#ac160e6c607b309d19b389258342b0505":[1,0,14,52],
"classCGAL_1_1General__polygon__set__2.html#ac18c32dc498a4a9f49a38f8351795dd6":[1,0,14,16],
"classCGAL_1_1General__polygon__set__2.html#ac4d7f7e338d1fb3149d443045b8448e4":[1,0,14,30],
"classCGAL_1_1General__polygon__set__2.html#ac69cd2db10652bd62a262e5931ea06e3":[1,0,14,29],
"classCGAL_1_1General__polygon__set__2.html#ac8708b6fd5a0a2c53c661e29acfe390a":[1,0,14,21],
"classCGAL_1_1General__polygon__set__2.html#acaff2dd99c5fdb57307f34b00cf8df15":[1,0,14,32],
"classCGAL_1_1General__polygon__set__2.html#ad6940f2a41ad01a486435467b736950c":[1,0,14,37],
"classCGAL_1_1General__polygon__set__2.html#ada373fa64e7acd4949d9d4e4ba34ef76":[1,0,14,18],
"classCGAL_1_1General__polygon__set__2.html#ada473e6e6863049a3daff4f4ba052ef4":[1,0,14,57],
"classCGAL_1_1General__polygon__set__2.html#ae0d978bb73a8e4e9488a30bd874431f2":[1,0,14,5],
"classCGAL_1_1General__polygon__set__2.html#ae273e6a6b96319cf0bbad008714d7336":[1,0,14,19],
"classCGAL_1_1General__polygon__set__2.html#ae519cff0b3a00b544da89c3cbf7e9419":[1,0,14,3],
"classCGAL_1_1General__polygon__set__2.html#ae7ad6d2242a520a5ed2c749f518bb51e":[1,0,14,44],
"classCGAL_1_1General__polygon__set__2.html#aed192585133c91397b72adab4ae81a65":[1,0,14,17],
"classCGAL_1_1General__polygon__set__2.html#aefab7ed30bca6bc4a4fd93a220f70456":[1,0,14,55],
"classCGAL_1_1General__polygon__set__2.html#af93dbce4007557da6b3c864ba6ec5011":[1,0,14,34],
"classCGAL_1_1General__polygon__set__2.html#af9452055544c5a2b1a62d896cb422d2c":[1,0,14,48],
"classCGAL_1_1General__polygon__set__2.html#afcd0109c06ffc04426405f533e554d03":[1,0,14,9],
"classCGAL_1_1Gps__circle__segment__traits__2.html":[1,0,15],
"classCGAL_1_1Gps__default__dcel.html":[1,0,12],
"classCGAL_1_1Gps__face__base.html":[1,0,10],
"classCGAL_1_1Gps__halfedge__base.html":[1,0,11],
"classCGAL_1_1Gps__segment__traits__2.html":[1,0,16],
"classCGAL_1_1Gps__segment__traits__2.html#a0cc0101117c17054490a84b4af91a44a":[1,0,16,0],
"classCGAL_1_1Gps__traits__2.html":[1,0,17],
"classCGAL_1_1Polygon__set__2.html":[1,0,18],
"classGeneralPolygonSetDcel.html":[1,0,0,8],
"classGeneralPolygonSetDcelFace.html":[1,0,0,9],
"classGeneralPolygonSetDcelFace.html#a0ba31caece98312b96a44f07f8eef681":[1,0,0,9,3],
"classGeneralPolygonSetDcelFace.html#a2ad35c52de20a0b53e1821f9e11971ec":[1,0,0,9,2],
"classGeneralPolygonSetDcelFace.html#a9a6897f38b2ae7b6ccba7f6012195363":[1,0,0,9,1],
"classGeneralPolygonSetDcelFace.html#a9d0bb56ecae8bb351162ec035e6862d1":[1,0,0,9,4],
"classGeneralPolygonSetDcelFace.html#ac0fbb57b7b5349cd8280f2e9c3afec6a":[1,0,0,9,6],
"classGeneralPolygonSetDcelFace.html#ad3083fcae1b26272f75503e25c7a8d91":[1,0,0,9,5],
"classGeneralPolygonSetDcelFace.html#adaebd8ae8f566af553b1f4eeffc78ca2":[1,0,0,9,0],
"classGeneralPolygonSetDcelHalfedge.html":[1,0,0,10],
"classGeneralPolygonSetDcelHalfedge.html#ab933b0c5beeeb25ff869ce58b35486c0":[1,0,0,10,0],
"classGeneralPolygonSetDcelHalfedge.html#ae4e52e7e80200b599d3e27003ae137e0":[1,0,0,10,1],
"classGeneralPolygonSetTraits__2.html":[1,0,0,11],
"classGeneralPolygonSetTraits__2.html#a044e46618764211b8717fd3918f8e399":[1,0,0,11,16],
"classGeneralPolygonSetTraits__2.html#a330299a6d6f8a9b3d35602888513de8f":[1,0,0,11,3],
"classGeneralPolygonSetTraits__2.html#a45dd5d5e3db466d29de0f94f5fd87bba":[1,0,0,11,12],
"classGeneralPolygonSetTraits__2.html#a4ad6b2c97c9e50646f38b9612cf76eef":[1,0,0,11,1],
"classGeneralPolygonSetTraits__2.html#a4b24cd40870dd9607e77ef84ed0e7c43":[1,0,0,11,11],
"classGeneralPolygonSetTraits__2.html#a6ad5f4a1fb6e2e848b15db43c8eebd6c":[1,0,0,11,6],
"classGeneralPolygonSetTraits__2.html#a75ad7bf0ef9959942d128d2f4ec33561":[1,0,0,11,2],
"classGeneralPolygonSetTraits__2.html#a7ec2fa1bc8b576c1cce3c22eeb069143":[1,0,0,11,0],
"classGeneralPolygonSetTraits__2.html#a8cd84c1c2cfd13abeebba291a1a2c516":[1,0,0,11,7],
"classGeneralPolygonSetTraits__2.html#a9856e77d66d40ae4dce2f7aee3677e3c":[1,0,0,11,5],
"classGeneralPolygonSetTraits__2.html#a9fd1cfd82b3162d3ac526dd8f5ef5a78":[1,0,0,11,9],
"classGeneralPolygonSetTraits__2.html#aa83ab7368ffb52cd04056ad9171728e3":[1,0,0,11,15],
"classGeneralPolygonSetTraits__2.html#ac33a7826e352bb8dec24815d3b1fc8a0":[1,0,0,11,8],
"classGeneralPolygonSetTraits__2.html#ac8239680e7616cab0477acc7faf5cd6c":[1,0,0,11,13],
"classGeneralPolygonSetTraits__2.html#ac8fd04db1596fe9d882a96caf97bc0df":[1,0,0,11,4],
"classGeneralPolygonSetTraits__2.html#ad04710dab5c3c434240627fdfb72ab73":[1,0,0,11,14],
"classGeneralPolygonSetTraits__2.html#afafa2d4b415735b77cbefabd71af42df":[1,0,0,11,10],
"classGeneralPolygon__2.html":[1,0,0,7],
"classGeneralPolygon__2.html#a0bedbf4f5a12f3b672227787b807e141":[1,0,0,7,7],
"classGeneralPolygon__2.html#a11747216c14f1252ec62b7d3d6f2190d":[1,0,0,7,9],
"classGeneralPolygon__2.html#a13c9ce25c0983fd9926d6f3a2637945a":[1,0,0,7,1],
"classGeneralPolygon__2.html#a381863cd4a42c9803306c74a5bf6740d":[1,0,0,7,3],
"classGeneralPolygon__2.html#a398ba60df8aedc71c4445f5b467015d4":[1,0,0,7,10],
"classGeneralPolygon__2.html#a44970dbde7e46f759d2ab9545c8c1a26":[1,0,0,7,11],
"classGeneralPolygon__2.html#a4b5104ea0a88dbe39a5240f04ee7db8d":[1,0,0,7,2],
"classGeneralPolygon__2.html#aab35e10aa9d465c39675da92a813be85":[1,0,0,7,8],
"classGeneralPolygon__2.html#aab80445fce8c22f894bc0268cef22e75":[1,0,0,7,0],
"classGeneralPolygon__2.html#adb04ad296966ddcd941720d32428f974":[1,0,0,7,4],
"classGeneralPolygon__2.html#aeae4de870ed8d4914e38a2863d30c219":[1,0,0,7,5],
"classGeneralPolygon__2.html#af914c0684481855c860173c4253aa06d":[1,0,0,7,6],
"classGpsTraitsGeneralPolygonWithHoles__2.html":[1,0,0,13],
"classGpsTraitsGeneralPolygon__2.html":[1,0,0,12],
"classGraphicsSceneOptionsPolygonSet2.html":[1,0,0,14],
"classGraphicsSceneOptionsPolygonSet2.html#a500973177f0e715044ffbb07797c690c":[1,0,0,14,4],
"classGraphicsSceneOptionsPolygonSet2.html#a5d4769e6916ada199d1d318780811bb3":[1,0,0,14,6],
"classGraphicsSceneOptionsPolygonSet2.html#a6c8eee44ee0031321ccba9dbf672e2fb":[1,0,0,14,2],
"classGraphicsSceneOptionsPolygonSet2.html#a71030449e557fb76a2319098a730d3a1":[1,0,0,14,3],
"classGraphicsSceneOptionsPolygonSet2.html#a88b81159e89b0ab27b21e62078b177cf":[1,0,0,14,0],
"classGraphicsSceneOptionsPolygonSet2.html#a93cffee9445e83d8d37a83220ac6a095":[1,0,0,14,8],
"classGraphicsSceneOptionsPolygonSet2.html#ac1dcdfe6bcfaf8a525cfe7d573d3fecb":[1,0,0,14,5],
"classGraphicsSceneOptionsPolygonSet2.html#ada686573abe87ea23d0f9705c8fd7fb6":[1,0,0,14,1],
"classGraphicsSceneOptionsPolygonSet2.html#adfe20e7a838280e093a9a90ba9839334":[1,0,0,14,7],
"examples.html":[5],
"generalizes.html":[2],
"group__PkgBooleanSetOperations2Concepts.html":[1,0,0],
"group__PkgBooleanSetOperations2Ref.html":[1,0],
"group__PkgDrawPolygonSet2.html":[1,0,1],
"group__PkgDrawPolygonSet2.html#ga027a46492fc3797d8beb712ccacc5237":[1,0,1,3],
"group__PkgDrawPolygonSet2.html#ga32083adbc962ea8ff36bd79f325f2cdb":[1,0,1,2],
"group__PkgDrawPolygonSet2.html#gac5ad1c3be15e88df46b096885a023ff4":[1,0,1,4],
"group__PkgDrawPolygonSet2.html#gad72ab78fd7b7e504dd1c55082ddd4454":[1,0,1,1],
"group__boolean__complement.html":[1,0,2],
"group__boolean__complement.html#ga067ea834c072d8c3fdcd4b752861310f":[1,0,2,7],
"group__boolean__complement.html#ga0c53208fd8a6c0b277d32f26488e1686":[1,0,2,9],
"group__boolean__complement.html#ga1fba4bb395af1556b59cc6d2f6d1c2a5":[1,0,2,3],
"group__boolean__complement.html#ga26b69b2b88a637d3e0ea01bd5087e0f0":[1,0,2,8],
"group__boolean__complement.html#ga3b61c1555b4a63aac0c695d2dd357b0d":[1,0,2,2],
"group__boolean__complement.html#ga45629253bda87736f21251bfee532665":[1,0,2,4],
"group__boolean__complement.html#ga76f005a9be0986ddb28009efabef5ae9":[1,0,2,0],
"group__boolean__complement.html#ga9600ad166a38cfc4be070d35041ff5e1":[1,0,2,5],
"group__boolean__complement.html#gac1a470ea0e369a9a5f7bf0911edc86d9":[1,0,2,1],
"group__boolean__complement.html#gae5b22437518e5cce7d23b93d9971187b":[1,0,2,6],
"group__boolean__connect__holes.html":[1,0,9],
"group__boolean__connect__holes.html#ga0c649fa14a7f93957b231d9a6bee29ae":[1,0,9,0],
"group__boolean__difference.html":[1,0,3],
"group__boolean__difference.html#ga052bf2179f0bfb044cf5701396d3c8e0":[1,0,3,15],
"group__boolean__difference.html#ga0c2f271e73693231ac7176d7a2e5c6e7":[1,0,3,16],
"group__boolean__difference.html#ga195f947f711bb7f77a827aa7d2eada8b":[1,0,3,11],
"group__boolean__difference.html#ga261debbed91d173658244642dffbcb30":[1,0,3,8],
"group__boolean__difference.html#ga2cb205944bed443d957d8294b6a82e47":[1,0,3,3],
"group__boolean__difference.html#ga503dbd4124f52fd06d3f9f07c77227f5":[1,0,3,4],
"group__boolean__difference.html#ga515ed8aa7e48fcf570a33dbd7e94d89d":[1,0,3,12],
"group__boolean__difference.html#ga5665ee87f6120f6afdc922f4efa6bddc":[1,0,3,18],
"group__boolean__difference.html#ga5edf64167f79ab37f80e0568a6781e16":[1,0,3,10],
"group__boolean__difference.html#ga652551cbb4eacfd4bc7b9467d6b725d0":[1,0,3,7],
"group__boolean__difference.html#ga7572c53b7b2af9c5a0b73a5bc542c358":[1,0,3,13],
"group__boolean__difference.html#ga7effc7f4302cfd2d9c331f448a394805":[1,0,3,1],
"group__boolean__difference.html#ga85e8919ac5202e328d394ed21f02958a":[1,0,3,5],
"group__boolean__difference.html#gaad09d58c2daf9b5c823ebc6b07e6c67f":[1,0,3,0],
"group__boolean__difference.html#gabe0c3adb2ede260678487eb57b3e0e47":[1,0,3,2],
"group__boolean__difference.html#gabe6eb8cc6be88d354c809ea729031afe":[1,0,3,19],
"group__boolean__difference.html#gada461352891344b389572edea2b2cb77":[1,0,3,14],
"group__boolean__difference.html#gae06f930ed133b9eb876ca1fcd407340b":[1,0,3,9],
"group__boolean__difference.html#gae62fd767e805095fc79d6fce319f2764":[1,0,3,17],
"group__boolean__difference.html#gafd39046000768bcda4d4824ea5aebc11":[1,0,3,6],
"group__boolean__do__intersect.html":[1,0,4],
"group__boolean__do__intersect.html#ga04fab69fdfe2f3578bcbc62996adc04e":[1,0,4,20],
"group__boolean__do__intersect.html#ga101934ce0a053b5d309ac6e2bcf070a3":[1,0,4,14],
"group__boolean__do__intersect.html#ga1bd35113abd947ac462b5d338ffcc0ae":[1,0,4,23],
"group__boolean__do__intersect.html#ga1e9c3901f9c7e3168b8bfdb09d01fdc8":[1,0,4,6],
"group__boolean__do__intersect.html#ga229ca9bbee66a870d022e31f5941dea2":[1,0,4,4],
"group__boolean__do__intersect.html#ga409ec40beeadbf237fb3e041585abdcc":[1,0,4,19],
"group__boolean__do__intersect.html#ga581533d4c15b23cc9ce7dfa7eec6bc17":[1,0,4,18],
"group__boolean__do__intersect.html#ga59e69e186188ee951ae092c66b0fa697":[1,0,4,13],
"group__boolean__do__intersect.html#ga62509b4d07bd4c9f686f0400e8d923b3":[1,0,4,3],
"group__boolean__do__intersect.html#ga7b0c4d2c7905afcf08a97577b18012eb":[1,0,4,7],
"group__boolean__do__intersect.html#ga7c6fd3409aae6c84fa5ffe022cb41e96":[1,0,4,10],
"group__boolean__do__intersect.html#ga8255959915dc17b5064c14641d768ef1":[1,0,4,15],
"group__boolean__do__intersect.html#ga84c826277e41f444dc4f32818bbbd178":[1,0,4,22],
"group__boolean__do__intersect.html#ga8b09dbbe610821a4a186f6d4de9a7f88":[1,0,4,1],
"group__boolean__do__intersect.html#ga908af873a4b13a618bdc045c8365c2c5":[1,0,4,8],
"group__boolean__do__intersect.html#ga98915fb1374be1cb82744952e0c7fbfb":[1,0,4,17],
"group__boolean__do__intersect.html#ga9f18568668ac51d487a9284e282f6c34":[1,0,4,16],
"group__boolean__do__intersect.html#gaa3476c1ad65cd3c742a52a9b5574499b":[1,0,4,12],
"group__boolean__do__intersect.html#gaa7cd339cba1f0c8eb0d337fe9f98790b":[1,0,4,21],
"group__boolean__do__intersect.html#gab4896fefa1edd0bdd518623cd7696754":[1,0,4,24],
"group__boolean__do__intersect.html#gab6d7fc757dc3503ea034f37db7aee5b0":[1,0,4,0],
"group__boolean__do__intersect.html#gabb7cb2710314cc30f9a6a22cf8f6e53d":[1,0,4,2],
"group__boolean__do__intersect.html#gabddfb44123eb80d6ddee4e3cf18d39ac":[1,0,4,25],
"group__boolean__do__intersect.html#gac0dd819320a2f80900e07809e2eb3e81":[1,0,4,11],
"group__boolean__do__intersect.html#gad003aabaa07bd93090ca827785a0f8b4":[1,0,4,9],
"group__boolean__do__intersect.html#gafba2c15fe9d73648b10bcafa60886a16":[1,0,4,5],
"group__boolean__intersection.html":[1,0,5],
"group__boolean__intersection.html#ga00686ff9801e75a7a4889a36e904c18a":[1,0,5,2],
"group__boolean__intersection.html#ga09c55e60dd0e46999efe828964c4d132":[1,0,5,9],
"group__boolean__intersection.html#ga13fed3218250b9171f43a0d15fb19fba":[1,0,5,17],
"group__boolean__intersection.html#ga24b18dfe78f8480ae03b9580f85aae4c":[1,0,5,16],
"group__boolean__intersection.html#ga29fce40369867c424dca950a3fbfdd08":[1,0,5,19],
"group__boolean__intersection.html#ga563341003db39158e0debffb5124cde5":[1,0,5,5],
"group__boolean__intersection.html#ga5deed25e21150a6524a5aa3e553dc7cf":[1,0,5,12],
"group__boolean__intersection.html#ga5deedf4ded78a0ed796ef3efaab46b79":[1,0,5,22]
};
